@@ -122,14 +122,19 @@ sub reconnect {
 
     $self->_in_transaction_check();
 
-    my $dbh = $self->{dbh};
-    $self->{dbh}->disconnect();
-    $self->owner_pid(undef);
+    $self->disconnect();
 
+    my $dbh = $self->{dbh};
     $self->{dbh} = $dbh->clone();
     $self->owner_pid($$);
 }
 
+sub disconnect {
+    my ($self) = @_;
+    $self->{dbh}->disconnect();
+    $self->owner_pid(undef);
+}
+
 sub dbh {
     my ($self) = @_;
     my $dbh = $self->{dbh};
@@ -324,6 +329,14 @@ returns DBIx::TransactionManager::ScopeGuard's instance. See L<DBIx::Transaction
 
 returns last_insert_id. (mysql_insertid in MySQL or last_insert_rowid in SQLite)
 
+=head2 disconnect
+
+disconnect database.
+
+=head2 reconnect
+
+reconnect database.
+
 
 =head1 LICENSE
 
